/*	
	hmc5843.h
	Mitch
*/

// some local earth mag field properties
# define declination -.103847	// this is west -5.95 deg in radians
//# define inclination 1.0377		// in radians
//# define ehx 24027.54
//# define ehy -2504.11
//# define ehz 40939.86 

typedef float	mf_t;	// base type of variable for calcs
typedef mf_t	mv_t[3]; // vector length 3
typedef mv_t	mm_t[3]; // matrix dims 3 x 3

// define a structure so bytes can be directly addressed
typedef	union bytetag 
	{	int i16; 
		struct {char lbyte; char hbyte; } b2; 
	}byte_union;

// define a 3d vector of integers
struct intvector
{	byte_union 	x,
				y,
				z;
};



// function initates a start condition on bus
void i2c_start(void);

//function initates a restart condition on bus
void i2c_restart(void);

//Resets the I2C bus to Idle
void reset_i2c_bus(void);

//This function will initialize the I2C(1) peripheral.
void InitI2C(void);

//basic I2C byte send
char send_i2c_byte(int data);

//function reads 1 byte of data, returns the read data
char i2c_read_byte(void);

//function reads data, returns the read data, with ack
//does not reset bus!!!
//char i2c_read_ack(void); 

// poll to check if a device is on the bus
//unsigned char I2Cpoll(char addr);

// write to an address
void I2Cwrite(char addr, char subaddr, char value);

// read from an address
char I2Cread(char addr, char subaddr);

// initialize hmc5843
void init_HMC5843(void);

// get new data 3 axis
void update_mag();

// read misc registers
void test_HMC5843(void); 

// return a true heading corrected for bank and pitch
float compass(float phi,float theta);

//calibrate magnetometer
void calibrate_magnetometer(void);

//return components
float magx(void);

float magy(void);

float magz(void);

// integer components as floats
float mx(void);

float my(void);

float mz(void);
