#include "adc.h"

// adc channels
#define ax 6			// sensor y axis
#define ay 0			// sensor x axis
#define az 1
#define gyro_p 7		// roll is sensor x rate
#define gyro_q 4		// pitch is sensor y rate 
#define gyro_r 5		// yaw


// conversions

float rad_to_deg(float inrad)
{ return (inrad * 57.2958); }

float deg_to_rad(float indeg)
{ return (indeg * .01745); }

// functions to return accelerometer values - are all used as ratios so scaling not required
// this axis should be towards the nose of the plane 
float accelero_x()
{	return ((float)adc_get_channel(ax) -32392.) / 669.	;}

// this axis should be towards the right wingtip 
float accelero_y()
{	return ((float)adc_get_channel(ay) -32712.) / 669. 	;}

// this axis should be towards the ground 
float accelero_z()
{	return -((float)adc_get_channel(az) -33500.) / 669.	;}

//gyro functions

/*
	.0033v / deg/sec 
 	(2^12 - 1)/3.3 =  1241 LSB per V ad converter
	1241 lsb/v * .0033 v/ deg/sec = 4.095 lsb / deg/sec
*/

float gyro_roll_dps() // p calibration in deg /sec
{	return (((float)adc_get_channel(gyro_p) -25050. ) /65.52  );	} // was 4.095

float gyro_pitch_dps() // q 
{	return (((float)adc_get_channel(gyro_q) -25040. ) /65.52  );	}

float gyro_yaw_dps() // r
{	return (((float)adc_get_channel(gyro_r) -24880. ) /65.52  );	}


float gyro_roll_rps()										// rad/sec
{	return deg_to_rad(gyro_roll_dps());	}

float gyro_pitch_rps()
{	return deg_to_rad(gyro_pitch_dps());	}

float gyro_yaw_rps()
{	return deg_to_rad(gyro_yaw_dps());	}
