// include file for vqm_lib.c

// type definitions
typedef double	f_t;	// base type of variable for calcs
//typedef f_t		v_t3[3]; // vector length 3
typedef f_t		v_t[6]; // vector length 6
typedef v_t		m_t[6]; // matrix dims 6x6
typedef int		iter_t; // iteration variables


// normalize a quaternion q
void v_normq(
	v_t	q_out,
const	v_t	q
);

void quat_mult(v_t qout, const v_t q1, const v_t q2);

void v_rotate(v_t vout, const v_t vin, const v_t qin);
 
void quat2euler(
	v_t	euler,
	const v_t	q
);
 


//vector functions

void v_zero(v_t c, iter_t n);

void v_norm(
	v_t	v_out,
	const v_t	v
);

 void v_add(
	v_t 		c,
	const v_t 	a,
	const v_t 	b,
	iter_t	n
);

 void v_sub(
	v_t 		c,
	const v_t 	a,
	const v_t 	b,
	iter_t		n
);



 void v_scale(
	v_t			c,
	const v_t	a,
	const f_t	s,
	iter_t		n
);
 
//matrix functions

 void m_zero(
	m_t			c,
	iter_t		m,
	iter_t		n
);
 
 void m_add(
	m_t 	c,
	m_t 	a,
	m_t		b,
	iter_t	m,
	iter_t	n
);

 void m_sub(
	m_t 		c,
	m_t 		a,
	m_t			b,
	iter_t		m,
	iter_t		n
);
 
 void m_scale(
	m_t			c,
	m_t			a,
	const f_t	s,
	iter_t		m,
	iter_t		n
);

// matrix vector add diagonal
// adds the vector a to corresponding diagonals in matrix b
 void mv_add_diag(
	m_t 			b,
	const v_t 		a,
	iter_t			n
);
 
 void mv_mult(
	v_t			vc,
	m_t			ma,
	const v_t	vb,
	iter_t		m,
	iter_t		n
);
 
 void vm_mult(
	v_t			vc,
	const v_t	va,
	m_t			mb,
	iter_t		m,
	iter_t		n
);
 
 void m_mult(
	m_t			c,
	m_t			a,
	m_t			b,
	iter_t		m,
	iter_t		n,
	iter_t		p
);

 void m_transpose(
	m_t			c,
	m_t			a,
	iter_t		m,
	iter_t		n
);
 
 f_t m33_det(m_t m);

 void m33_inv(
	m_t			D,
	m_t			m
);

 void m_print(
	const char *label,
	m_t			a,
	iter_t		m,
	iter_t		n
);

void v_print(
	const char *label,
	v_t			a,
	iter_t		n
);
 
